---
title: Python API
---

Open Targets Gentropy is a Python package to facilitate the interpretation and analysis of GWAS and functional genomic studies for target identification.

The package contains a toolkit for the harmonisation, statistical analysis and prioritisation of genetic signals to assist drug discovery.

## Data model

Gentropy data model is build upon following concepts:

- [**Data Sources**](datasources/_datasources.md): data sources harmonisation tools
- [**Datasets**](datasets/_datasets.md): data model
- [**Methods**](methods/_methods.md): statistical analysis tools
- [**Steps**](steps/_steps.md): pipeline steps
- [**Common**](common/_common.md): Common classes
- [**Assets**](assets/_assets.md): Assets used in gentropy package
